==> ocp-common-5.0.0-20211122.032646-66-sources.jar: com/efuture/ocp/common/rest/ServiceVersion.java <==
/**
 * Copyright (C), 2007-2014, eFuture 北京富基融通科技有限公司
 * FileName:	ServiceVersion.java
 * Author:		亮
 * Date:		2014-10-31 上午9:42:23
 * Description:	
 * History:
 * <author>		<time>			<version>		<description>
 * 
 */
package com.efuture.ocp.common.rest;

import java.math.BigDecimal;
import java.text.DecimalFormat;
import java.util.HashMap;
import java.util.Map;
import java.util.TreeMap;

import com.efuture.ocp.common.util.*;
import org.apache.log4j.Logger;

import com.alibaba.fastjson.JSONObject;
import org.springframework.util.StringUtils;

/**
 * @author		亮
 * @description	
 * 
 */
public class ServiceVersion
{
    Logger logger = Logger.getLogger(ServiceVersion.class);
    boolean logstatus;
    
    String logformat;

    public String getLogFormat()
    {
		if (logformat == null) {
			return "default";
		}
		return logformat;
	}

    public void setLogFormat(String logFormat)
    {
		this.logformat = logFormat;
	}
	String ver;    
    public ServiceVersion(String version, String openlog)
    {
    	//ServiceVersion(version,openlog,"default");
    	ver = version;
        logstatus = openlog.equalsIgnoreCase("y");
        setLogFormat("default");
    }
    
    public ServiceVersion(String version, String openlog,String logformat)
    {
        ver = version;
        logstatus = openlog.equalsIgnoreCase("y");
        setLogFormat(logformat);
    }
    public ServiceVersion(String version)
    {
        ver = version;
    }
    
    public String getVer()
    {
        return ver;
    }

    public boolean isLogstatus()
    {
        return logstatus;
    }

    public void setLogstatus(boolean logstatus)
    {
        this.logstatus = logstatus;
    }

    public void debugLog(Object message)
    {
        if (logstatus) {
            logger.info(message);
        }
    }

    String sinceTime = DateUtils.getNowStr();
    Map<String, JSONObject> elapsed = new TreeMap<>();
    long[] elapsedStep = new long[]{200,300,500,1000,3000,5000};
    String[] elapsedKeys = new String[]{"<=200","200-300","300-500","500-1000","1000-3000","3000-5000",">5000"};
    DecimalFormat df = new DecimalFormat(",###");

    public Map<String, JSONObject> getElapsed()
    {
        return elapsed;
    }
    public void setElapsed(Map<String, JSONObject> elapsed)
    {
        this.elapsed = elapsed;
    }
    private String formatNumber(String num) {
        if (StringUtils.isEmpty(num))
        {
            return "&nbsp;";
        }
        return df.format(new BigDecimal(num));
    }

    private String getHostPort() {
        String result = "";
        try
        {
            result = result.concat( NetworkUtils.getLocalIP() );
        }
        catch (Exception ex)
        {
            result = result.concat("0.0.0.0");
        }
        try
        {
            result = result.concat(":").concat( NetworkUtils.getLocalPort() );
        }
        catch (Exception ex)
        {
            result = result.concat(":0000");
        }
        return result;
    }

    public String printElapsed() throws Exception
    {
        StringBuilder sb = new StringBuilder(  );
        sb.append("<style>" );
        sb.append("table{border:1px solid #cad9ea;text-align:center;cellspacing:0px;cellpadding:50px} ");
        sb.append("table th{border:1px solid #cad9ea;text-align:center;cellspacing:0px;cellpadding:50px} " );
        sb.append("table tr td{border:1px solid #cad9ea;text-align:center;cellspacing:0px;cellpadding:50px} ");
        sb.append("</style>");
        String[] active = EnviromentUtil.getEnv().getActiveProfiles();
        if (active != null && active.length > 0) {
            sb.append("Active:&ensp;").append( active[0] ).append( "<br>" );
        }
        sb.append("IPAddr: ").append( getHostPort() ).append( "<br>" );
        sb.append("Since:&ensp;&ensp;").append( sinceTime ).append( "<br>" );
        sb.append( "<TABLE>" );
        boolean printHeader = false;
        for (Map.Entry<String, JSONObject> entry : elapsed.entrySet()) {
            if (!printHeader) {
                sb.append( "<tr style='background-color: #CCE8EB;'>" );
                sb.append("<td rowspan=2>方法</td>");
                sb.append("<td rowspan=2>调用次数</td>");
                sb.append("<td rowspan=2>累计耗时<br>(ms)</td>");
                sb.append("<td rowspan=2>平均耗时<br>(ms)</td>");
                sb.append("<td rowspan=2>最低耗时<br>(ms)</td>");
                sb.append("<td rowspan=2>最高耗时<br>(ms)</td>");
                sb.append("<td colspan=" + String.valueOf(elapsedKeys.length ) + ">分段统计(次数)</td>");
                sb.append("</tr><tr style='background-color: #CCE8EB'>" );
                for (String s : elapsedKeys) {
                    sb.append("<td>");
                    sb.append( s );
                    sb.append("</td>");
                }
                sb.append( "</tr><tr>" );
                printHeader = true;
            }
            else {
                sb.append( "<tr>" );
            }
            sb.append("<td style='text-align:left'>" + entry.getKey() + "</td>");
            sb.append( "<td>" + formatNumber(DataUtils.getJsonData(entry.getValue(), "num", false, "0")) + "</td>");
            sb.append("<td>" + formatNumber(DataUtils.getJsonData(entry.getValue(), "tot", false, "0")) + "</td>");
            sb.append("<td>" + formatNumber(DataUtils.getJsonData(entry.getValue(), "avg", false, "0")) + "</td>");
            sb.append("<td>" + formatNumber(DataUtils.getJsonData(entry.getValue(), "min", false, "0")) + "</td>");
            sb.append("<td>" + formatNumber(DataUtils.getJsonData(entry.getValue(), "max", false, "0")) + "</td>");
            for (String s : elapsedKeys) {
                sb.append("<td>");
                sb.append( formatNumber(DataUtils.getJsonData(entry.getValue(), s, false, "")) );
                sb.append("</td>");
            }
            sb.append( "</tr>" );
        }
        sb.append( "<TABLE>" );
        return sb.toString();
    }
    
    public synchronized void writeElapsed(String key,long time)
    {
        try {
        	// 0耗时的不记录
            if (time <= 0) {
                return;
            }
        	
            // 总次数,总耗时,平均耗时
        	JSONObject json = elapsed.get(key);
            if (json == null) {
                json = new JSONObject();
                json.put("num", 1);
                json.put("tot", time);
                json.put("avg", time);
                json.put("min", time);
                json.put("max", time);
                this.elapsed.put(key,json);
            }
            else {
                json.put("num", json.getLong("num")+1);                
                json.put("tot", json.getLong("tot")+time);
                json.put("avg", json.getLong("tot") / json.getLong("num"));
                json.put("min", Math.min(json.getLong("min"), time));
                json.put("max", Math.max(json.getLong("max"), time));
            }
            
            // 分档耗时
            boolean exist = false;
            for (int i = 0; i < elapsedStep.length; i++) {
                if (time <= elapsedStep[i]) {
                    String str = (i > 0 ? elapsedStep[i-1] + "-" + elapsedStep[i] : "<=" + elapsedStep[i]);
                    if (json.containsKey(str)) {
                        json.put(str, json.getLong(str) + 1);
                    }
                    else {
                        json.put(str, 1);
                    }
                    
                    exist = true;
                    break;
                }
            }
            if (!exist) {
                String str = ">" + elapsedStep[elapsedStep.length-1];
                if (json.containsKey(str)) {
                    json.put(str, json.getLong(str) + 1);
                }
                else {
                    json.put(str, 1);
                }
            }
        }
        catch (Exception ex) {
        }
    }

    public synchronized void cleanElapsed() throws Exception
    {
        elapsed.clear();
    }
    
    public static ServiceVersion getInstance()
    {
        ServiceVersion sv = SpringBeanFactory.getBean("ServiceVersion",ServiceVersion.class);
        return sv;
    }
    
    public static String getVersion()
    {
        return getInstance().getVer();
    }
    
}

==> ocp-common-5.0.0-20211122.054823-70-sources.jar: com/efuture/ocp/common/rest/ServiceVersion.java <==
/**
 * Copyright (C), 2007-2014, eFuture 北京富基融通科技有限公司
 * FileName:	ServiceVersion.java
 * Author:		亮
 * Date:		2014-10-31 上午9:42:23
 * Description:	
 * History:
 * <author>		<time>			<version>		<description>
 * 
 */
package com.efuture.ocp.common.rest;

import java.math.BigDecimal;
import java.text.DecimalFormat;
import java.util.HashMap;
import java.util.Map;
import java.util.TreeMap;

import com.efuture.ocp.common.util.*;
import org.apache.log4j.Logger;

import com.alibaba.fastjson.JSONObject;
import org.springframework.util.StringUtils;

/**
 * @author		亮
 * @description	
 * 
 */
public class ServiceVersion
{
    Logger logger = Logger.getLogger(ServiceVersion.class);
    boolean logstatus;
    
    String logformat;

    public String getLogFormat()
    {
		if (logformat == null) {
			return "default";
		}
		return logformat;
	}

    public void setLogFormat(String logFormat)
    {
		this.logformat = logFormat;
	}
	String ver;    
    public ServiceVersion(String version, String openlog)
    {
    	//ServiceVersion(version,openlog,"default");
    	ver = version;
        logstatus = openlog.equalsIgnoreCase("y");
        setLogFormat("default");
    }
    
    public ServiceVersion(String version, String openlog,String logformat)
    {
        ver = version;
        logstatus = openlog.equalsIgnoreCase("y");
        setLogFormat(logformat);
    }
    public ServiceVersion(String version)
    {
        ver = version;
    }
    
    public String getVer()
    {
        return ver;
    }

    public boolean isLogstatus()
    {
        return logstatus;
    }

    public void setLogstatus(boolean logstatus)
    {
        this.logstatus = logstatus;
    }

    public void debugLog(Object message)
    {
        if (logstatus) {
            logger.info(message);
        }
    }

    String sinceTime = DateUtils.getNowStr();
    Map<String, JSONObject> elapsed = new TreeMap<>();
    long[] elapsedStep = new long[]{200,300,500,1000,3000,5000};
    String[] elapsedKeys = new String[]{"<=200","200-300","300-500","500-1000","1000-3000","3000-5000",">5000"};
    DecimalFormat df = new DecimalFormat(",###");

    public Map<String, JSONObject> getElapsed()
    {
        return elapsed;
    }
    public void setElapsed(Map<String, JSONObject> elapsed)
    {
        this.elapsed = elapsed;
    }
    private String formatNumber(String num) {
        if (StringUtils.isEmpty(num))
        {
            return "&nbsp;";
        }
        return df.format(new BigDecimal(num));
    }

    private String getHostPort() {
        String result = "";
        try
        {
            result = result.concat( NetworkUtils.getLocalIP() );
        }
        catch (Exception ex)
        {
            result = result.concat("0.0.0.0");
        }
        try
        {
            result = result.concat(":").concat( NetworkUtils.getLocalPort() );
        }
        catch (Exception ex)
        {
        }
        return result;
    }

    public String printElapsed() throws Exception
    {
        StringBuilder sb = new StringBuilder(  );
        sb.append("<style>" );
        sb.append("table{border:1px solid #cad9ea;text-align:center;cellspacing:0px;cellpadding:50px} ");
        sb.append("table th{border:1px solid #cad9ea;text-align:center;cellspacing:0px;cellpadding:50px} " );
        sb.append("table tr td{border:1px solid #cad9ea;text-align:center;cellspacing:0px;cellpadding:50px} ");
        sb.append("</style>");
        String[] active = EnviromentUtil.getEnv().getActiveProfiles();
        if (active != null && active.length > 0) {
            sb.append("&ensp;&ensp;Active: ").append( active[0] ).append( "<br>" );
        }
        sb.append("&ensp;IPAddr: ").append( getHostPort() ).append( "<br>" );
        sb.append("&ensp;&ensp;&ensp;Since: ").append( sinceTime ).append( "<br>" );
        sb.append( "<TABLE>" );
        boolean printHeader = false;
        for (Map.Entry<String, JSONObject> entry : elapsed.entrySet()) {
            if (!printHeader) {
                sb.append( "<tr style='background-color: #CCE8EB;'>" );
                sb.append("<td rowspan=2>方法</td>");
                sb.append("<td rowspan=2>调用次数</td>");
                sb.append("<td rowspan=2>累计耗时<br>(ms)</td>");
                sb.append("<td rowspan=2>平均耗时<br>(ms)</td>");
                sb.append("<td rowspan=2>最低耗时<br>(ms)</td>");
                sb.append("<td rowspan=2>最高耗时<br>(ms)</td>");
                sb.append("<td colspan=" + String.valueOf(elapsedKeys.length ) + ">分段统计(次数)</td>");
                sb.append("</tr><tr style='background-color: #CCE8EB'>" );
                for (String s : elapsedKeys) {
                    sb.append("<td>");
                    sb.append( s );
                    sb.append("</td>");
                }
                sb.append( "</tr><tr>" );
                printHeader = true;
            }
            else {
                sb.append( "<tr>" );
            }
            sb.append("<td style='text-align:left'>" + entry.getKey() + "</td>");
            sb.append( "<td>" + formatNumber(DataUtils.getJsonData(entry.getValue(), "num", false, "0")) + "</td>");
            sb.append("<td>" + formatNumber(DataUtils.getJsonData(entry.getValue(), "tot", false, "0")) + "</td>");
            sb.append("<td>" + formatNumber(DataUtils.getJsonData(entry.getValue(), "avg", false, "0")) + "</td>");
            sb.append("<td>" + formatNumber(DataUtils.getJsonData(entry.getValue(), "min", false, "0")) + "</td>");
            sb.append("<td>" + formatNumber(DataUtils.getJsonData(entry.getValue(), "max", false, "0")) + "</td>");
            for (String s : elapsedKeys) {
                sb.append("<td>");
                sb.append( formatNumber(DataUtils.getJsonData(entry.getValue(), s, false, "")) );
                sb.append("</td>");
            }
            sb.append( "</tr>" );
        }
        sb.append( "<TABLE>" );
        return sb.toString();
    }
    
    public synchronized void writeElapsed(String key,long time)
    {
        try {
        	// 0耗时的不记录
            if (time <= 0) {
                return;
            }
        	
            // 总次数,总耗时,平均耗时
        	JSONObject json = elapsed.get(key);
            if (json == null) {
                json = new JSONObject();
                json.put("num", 1);
                json.put("tot", time);
                json.put("avg", time);
                json.put("min", time);
                json.put("max", time);
                this.elapsed.put(key,json);
            }
            else {
                json.put("num", json.getLong("num")+1);                
                json.put("tot", json.getLong("tot")+time);
                json.put("avg", json.getLong("tot") / json.getLong("num"));
                json.put("min", Math.min(json.getLong("min"), time));
                json.put("max", Math.max(json.getLong("max"), time));
            }
            
            // 分档耗时
            boolean exist = false;
            for (int i = 0; i < elapsedStep.length; i++) {
                if (time <= elapsedStep[i]) {
                    String str = (i > 0 ? elapsedStep[i-1] + "-" + elapsedStep[i] : "<=" + elapsedStep[i]);
                    if (json.containsKey(str)) {
                        json.put(str, json.getLong(str) + 1);
                    }
                    else {
                        json.put(str, 1);
                    }
                    
                    exist = true;
                    break;
                }
            }
            if (!exist) {
                String str = ">" + elapsedStep[elapsedStep.length-1];
                if (json.containsKey(str)) {
                    json.put(str, json.getLong(str) + 1);
                }
                else {
                    json.put(str, 1);
                }
            }
        }
        catch (Exception ex) {
        }
    }

    public synchronized void cleanElapsed() throws Exception
    {
        elapsed.clear();
    }
    
    public static ServiceVersion getInstance()
    {
        ServiceVersion sv = SpringBeanFactory.getBean("ServiceVersion",ServiceVersion.class);
        return sv;
    }
    
    public static String getVersion()
    {
        return getInstance().getVer();
    }
    
}
